# `members_package`

Docstring for the package.

## `module_attribute = 42` `module-attribute`

Docstring for `module_attribute` .

## `Class`

Docstring for `Class` .

### `class_attribute = 42` `class-attribute` `instance-attribute`

Docstring for `Class.class_attribute` .

### `instance_attribute = a + b` `instance-attribute`

Docstring for `Class.instance_attribute` .

### `NestedClass`

Docstring for `NestedClass` .

### `__init__ ( a , b )`

Docstring for `Class.__init__` .

### `method1 ( a , b )`

Docstring for `Class.method1` .

### `method2 ( a , b )`

Docstring for `Class.method2` .

## `Subclass`

Bases: `Class`

Docstring for `Subclass` .

## `module_function ( a , b )`

Docstring for `module_function` .